diff --git a/doc/src/sgml/ref/psql-ref.sgml b/doc/src/sgml/ref/psql-ref.sgml
index ee6ec3a..6a172dc 100644
--- a/doc/src/sgml/ref/psql-ref.sgml
+++ b/doc/src/sgml/ref/psql-ref.sgml
@@ -556,6 +556,15 @@ EOF
       </listitem>
     </varlistentry>
 
+    <varlistentry>
+      <term><option>--help-variables</></term>
+      <listitem>
+      <para>
+      Show help about <application>psql</application> variables,
+      and exit.
+      </para>
+      </listitem>
+    </varlistentry>
   </variablelist>
  </refsect1>
 
diff --git a/src/bin/psql/help.c b/src/bin/psql/help.c
index 3aa3c16..9ff2dd9 100644
--- a/src/bin/psql/help.c
+++ b/src/bin/psql/help.c
@@ -78,12 +78,13 @@ usage(void)
 	printf(_("  -f, --file=FILENAME      execute commands from file, then exit\n"));
 	printf(_("  -l, --list               list available databases, then exit\n"));
 	printf(_("  -v, --set=, --variable=NAME=VALUE\n"
-			 "                           set psql variable NAME to VALUE\n"));
+			 "                           set psql variable NAME to VALUE e.g.: -v ON_ERROR_STOP=1\n"));
 	printf(_("  -V, --version            output version information, then exit\n"));
 	printf(_("  -X, --no-psqlrc          do not read startup file (~/.psqlrc)\n"));
 	printf(_("  -1 (\"one\"), --single-transaction\n"
 			 "                           execute as a single transaction (if non-interactive)\n"));
 	printf(_("  -?, --help               show this help, then exit\n"));
+	printf(_("  --help-variables         show a list of all specially treated variables, then exit\n"));
 
 	printf(_("\nInput and output options:\n"));
 	printf(_("  -a, --echo-all           echo all input from script\n"));
@@ -279,6 +280,99 @@ slashUsage(unsigned short int pager)
 }
 
 
+/*
+ * show list of available variables (options) from command line
+ */
+void
+help_variables(void)
+{
+	printf(_("List of specially treated variables.\n"));
+
+	printf(_("psql variables:\n"));
+	printf(_("Usage:\n"));
+	printf(_("  psql --set=NAME=VALUE\n  or \\set NAME VALUE in interactive mode\n\n"));
+
+	printf(_("  AUTOCOMMIT         if set, successful SQL commands are automatically committed\n"));
+	printf(_("  COMP_KEYWORD_CASE  determine the case used to complete SQL keywords\n"
+					 "                     [lower, upper, preserve-lower, preserve-upper]\n"));
+	printf(_("  DBNAME             the currently connected database name\n"));
+	printf(_("  ECHO               control what input is written to standard output [all, queries]\n"));
+	printf(_("  ECHO_HIDDEN        display internal queries executed by backslash commands\n"));
+	printf(_("  ENCODING           current client character set encoding\n"));
+	printf(_("  FETCH_COUNT        the number of result rows to fetch and display at a time\n"
+					 "                     (default: 0=unlimited)\n"));
+	printf(_("  HISTCONTROL        control history list [ignorespace, ignoredups, ignoreboth]\n"));
+	printf(_("  HISTFILE           file name used to store the history list\n"));
+	printf(_("  HISTSIZE           the number of commands to store in the command history\n"));
+	printf(_("  HOST               the currently connected database server\n"));
+	printf(_("  IGNOREEOF          if unset, sending an EOF to interactive session terminates application\n"));
+	printf(_("  LASTOID            the value of last affected OID\n"));
+	printf(_("  ON_ERROR_ROLLBACK  if set, an error doesn't stop a transaction (uses implicit SAVEPOINTs)\n"));
+	printf(_("  ON_ERROR_STOP      stop batch execution after error\n"));
+	printf(_("  PORT               server port of the current connection\n"));
+	printf(_("  PROMPT1, PROMPT2, PROMPT3\n"
+					 "                     specify the psql prompt\n"));
+	printf(_("  QUIET              run quietly (same as -q option)\n"));
+	printf(_("  SINGLELINE         end of line terminates SQL command mode (same as -S option)\n"));
+	printf(_("  SINGLESTEP         single-step mode (same as -s option)\n"));
+	printf(_("  USER               the currently connected database user\n"));
+	printf(_("  VERBOSITY          control verbosity of error reports [default, verbose, terse]\n"));
+
+	printf(_("\nPrinting options:\n"));
+	printf(_("Usage:\n"));
+	printf(_("  psql --pset=NAME[=VALUE]\n  or \\pset NAME [VALUE] in interactive mode\n\n"));
+
+	printf(_("  border             border style (number)\n"));
+	printf(_("  columns            set the target width for the wrapped format\n"));
+	printf(_("  expanded (or x)    toggle expanded output\n"));
+	printf(_("  fieldsep           field separator for unaligned output (default '|')\n"));
+	printf(_("  fieldsep_zero      set field separator in unaligned mode to zero\n"));
+	printf(_("  format             set output format [unaligned, aligned, wrapped, html, latex, ..]\n"));
+	printf(_("  footer             enable or disable display of the table footer [on, off]\n"));
+	printf(_("  linestyle          set the border line drawing style [ascii, old-ascii, unicode]\n"));
+	printf(_("  null               set the string to be printed in place of a null value\n"));
+	printf(_("  numericlocale      enable or disable display of a locale-specific character to separate\n"
+					 "                     groups of digits [on, off]\n"));
+	printf(_("  pager              control when an external pager is used [yes, no, always]\n"));
+	printf(_("  recordsep          specify the record (line) separator to use in unaligned output format\n"));
+	printf(_("  recordsep_zero     set the record separator to use in unaligned output format to a zero byte.\n"));
+	printf(_("  tableattr (or T)   specify attributes for table tag in html format or proportional\n"
+					 "                     column width of left aligned data type in latex format\n"));
+	printf(_("  title              set the table title for any subsequently printed tables\n"));
+	printf(_("  tuples_only        if set, only actual table data is shown\n"));
+
+	printf(_("\nEnvironment variables:\n"));
+	printf(_("Usage:\n"));
+
+#ifndef WIN32
+	printf(_("  NAME=VALUE [NAME=VALUE] psql ...\n  or \\setenv NAME [VALUE] in interactive mode\n\n"));
+#else
+	printf(_("  set NAME=VALUE\n  psql ...\n  or \\setenv NAME VALUE in interactive mode\n\n"));
+#endif
+
+	printf(_("  COLUMNS            number of columns for wrapped format\n"));
+	printf(_("  PAGER              name of external pager program\n"));
+	printf(_("  PGAPPNAME          same as the application_name connection parameter\n"));
+	printf(_("  PGDATABASE         same as the dbname connection parameter\n"));
+	printf(_("  PGHOST             same as the host connection parameter\n"));
+	printf(_("  PGPORT             same as the port connection parameter\n"));
+	printf(_("  PGUSER             same as the user connection parameter\n"));
+	printf(_("  PGPASSWORD         connection password (not recommended)\n"));
+	printf(_("  PGPASSFILE         password file name\n"));
+	printf(_("  PSQL_EDITOR, EDITOR, VISUAL\n"
+					 "                     editor used by the \\e and \\ef commands\n"));
+	printf(_("  PSQL_EDITOR_LINENUMBER_ARG\n"
+					 "                     how to specify a line number when invoking the editor\n"));
+	printf(_("  PSQL_HISTORY       alternative location for the command history file\n"));
+	printf(_("  PSQLRC             alternative location for the user's .psqlrc file\n"));
+	printf(_("  SHELL              shell used by the \\! command\n"));
+	printf(_("  TMPDIR             directory for temporary files\n"));
+
+	printf(_("\nFor more information consult the psql section in the PostgreSQL\n"
+			 "documentation.\n\n"));
+	printf(_("Report bugs to <pgsql-bugs@postgresql.org>.\n"));
+}
+
 
 /*
  * helpSQL -- help with SQL commands
diff --git a/src/bin/psql/help.h b/src/bin/psql/help.h
index 054d5a4..e7affff 100644
--- a/src/bin/psql/help.h
+++ b/src/bin/psql/help.h
@@ -12,6 +12,8 @@ void		usage(void);
 
 void		slashUsage(unsigned short int pager);
 
+void		help_variables(void);
+
 void		helpSQL(const char *topic, unsigned short int pager);
 
 void		print_copyright(void);
diff --git a/src/bin/psql/startup.c b/src/bin/psql/startup.c
index 45653a1..d911159 100644
--- a/src/bin/psql/startup.c
+++ b/src/bin/psql/startup.c
@@ -383,6 +383,7 @@ parse_psql_options(int argc, char *argv[], struct adhoc_opts * options)
 		{"expanded", no_argument, NULL, 'x'},
 		{"no-psqlrc", no_argument, NULL, 'X'},
 		{"help", no_argument, NULL, '?'},
+		{"help-variables", no_argument, NULL, 1},
 		{NULL, 0, NULL, 0}
 	};
 
@@ -566,6 +567,9 @@ parse_psql_options(int argc, char *argv[], struct adhoc_opts * options)
 					exit(EXIT_FAILURE);
 				}
 				break;
+			case 1:
+				help_variables();
+				exit(EXIT_SUCCESS);
 			default:
 				fprintf(stderr, _("Try \"%s --help\" for more information.\n"),
 						pset.progname);
